# -*- coding: utf-8 -*-
# Generated by Django 1.10 on 2016-08-24 14:45
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('budget', '0023_auto_20160819_1310'),
    ]

    operations = [
        migrations.AlterField(
            model_name='change',
            name='at',
            field=models.DateTimeField(auto_now_add=True),
        ),
    ]
