# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2017-11-14 19:22
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('budget', '0038_auto_20171028_1706'),
    ]

    operations = [
        migrations.AddField(
            model_name='contentplacement',
            name='page_number',
            field=models.PositiveSmallIntegerField(blank=True, null=True),
        ),
    ]
