# -*- coding: utf-8 -*-
# Generated by Django 1.9.6 on 2016-06-27 16:20
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('budget', '0013_auto_20160627_1006'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='item',
            name='subscribers',
        ),
    ]
