# -*- coding: utf-8 -*-
# Generated by Django 1.9.6 on 2016-05-31 22:48
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('budget', '0006_auto_20160531_1717'),
    ]

    operations = [
        migrations.AlterField(
            model_name='printpublication',
            name='is_active',
            field=models.BooleanField(default=True, help_text=b'Should this publication be included in the current options users can choose from? If false, this publication will be archived, but it may be re-activated in the future.', verbose_name=b'Active?'),
        ),
    ]
