# -*- coding: utf-8 -*-
# Generated by Django 1.9 on 2016-05-31 15:58
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('budget', '0004_auto_20160424_1343'),
    ]

    operations = [
        migrations.AlterField(
            model_name='item',
            name='type',
            field=models.CharField(choices=[(b'text', b'Text'), (b'photo', b'Photo'), (b'video', b'Video'), (b'audio', b'Audio'), (b'graphic', b'Graphic'), (b'interactive', b'Interactive'), (b'aggregation', b'Aggregation'), (b'other', b'Other')], default=b'text', max_length=25),
        ),
    ]
